summaryrefslogtreecommitdiffstats
path: root/lib/util/urlutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/urlutil.h')
-rw-r--r--lib/util/urlutil.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/lib/util/urlutil.h b/lib/util/urlutil.h
index 65e96a56..e8c84607 100644
--- a/lib/util/urlutil.h
+++ b/lib/util/urlutil.h
@@ -21,8 +21,8 @@
#ifndef _URLUTIL_H_
#define _URLUTIL_H_
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
#include <kurl.h>
/**
@@ -43,12 +43,12 @@ namespace URLUtil
* @return The filename part of a pathname (i.e. everything past the last slash).
* @param pathName The absolute path to a file.
*/
- QString filename(const QString & pathName);
+ TQString filename(const TQString & pathName);
/**
* @return The directory part of a path (i.e. everything up to but not including the last slash)
* @param pathName The absolute path to a directory.
*/
- QString directory(const QString & pathName);
+ TQString directory(const TQString & pathName);
/**
* @return The relative path between a parent and child URL, or blank if the specified
* child is not a child of parent.
@@ -59,7 +59,7 @@ namespace URLUtil
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- QString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a parent and child URL, or blank if the specified
* child is not a child of parent.
@@ -70,13 +70,13 @@ namespace URLUtil
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- QString relativePath(const QString & parent, const QString & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const TQString & parent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a base path and destination path or.
* @param base The base Path.
* @param dest The destination path.
*/
- QString getRelativePath( const QString& base, const QString& dest );
+ TQString getRelativePath( const TQString& base, const TQString& dest );
/**
* @param dirUrl An URL of a directory.
* @param fileUrl An URL of a file.
@@ -86,13 +86,13 @@ namespace URLUtil
* fileUrl: /home/test/lib/mylib.cpp
* returns: ../lib/mylib.cpp</pre>
*/
- QString relativePathToFile( const QString & dirUrl, const QString & fileUrl );
+ TQString relativePathToFile( const TQString & dirUrl, const TQString & fileUrl );
/**
*@param path A path (absolute or relative).
*@param slashSuffix if true then "/" is appended to a path.
*@returns The path 'up one level' - the opposite of what filename returns.
*/
- QString upDir(const QString & path, bool slashSuffix = false);
+ TQString upDir(const TQString & path, bool slashSuffix = false);
/**
* 'Merges' URLs - changes a URL that starts with dest to start with source instead.\n
* <pre>Example:
@@ -110,7 +110,7 @@ namespace URLUtil
* @return The file extension for a filename or path.
* @param path Absolute or relative path.
*/
- QString getExtension(const QString & path);
+ TQString getExtension(const TQString & path);
/**
* Given a base directory url in @p baseDirUrl and the url referring to the
@@ -120,8 +120,8 @@ namespace URLUtil
* KURL baseUrl, dirUrl;
* baseUrl.setPath( "/home/mario/src/kdevelop/" );
* dirUrl.setPath( "/home/mario/src/kdevelop/parts/cvs/" );
* QString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
* QString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
* @endcode
* Note that if you pass a file name in @p url (instead of a directory) or the
* @p baseUrl is not contained in @p url then the function will return "" (void string).
@@ -130,25 +130,25 @@ namespace URLUtil
* @param url Base directory URL.
* @return The relative path between @p url and @p baseDirUrl.
*/
- QString extractPathNameRelative(const KURL &baseDirUrl, const KURL &url );
- /**Same as above. @p basePath is QString.*/
- QString extractPathNameRelative(const QString &basePath, const KURL &url );
+ TQString extractPathNameRelative(const KURL &baseDirUrl, const KURL &url );
+ /**Same as above. @p basePath is TQString.*/
+ TQString extractPathNameRelative(const TQString &basePath, const KURL &url );
/**Same as above. Both @p basePath and @p absFilePath are QStrings.*/
- QString extractPathNameRelative(const QString &basePath, const QString &absFilePath );
+ TQString extractPathNameRelative(const TQString &basePath, const TQString &absFilePath );
/**
* @param url The url to extract the absolute path from.
* @return The absolute path name referred in @p url.
* Look at @ref extractPathNameRelative documentation for an example.
*/
- QString extractPathNameAbsolute( const KURL &url );
+ TQString extractPathNameAbsolute( const KURL &url );
/**
* @param baseDir Base directory for relative URLs.
* @param urls The list of urls to extract the relative paths from.
* @return A QStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls.
*/
- QStringList toRelativePaths( const QString &baseDir, const KURL::List &urls);
+ TQStringList toRelativePaths( const TQString &baseDir, const KURL::List &urls);
/**
* @param url The absolute URL.
@@ -159,7 +159,7 @@ namespace URLUtil
* @param absFilePath The absolute path.
* @return true if @p url is a directory, false otherwise.
*/
- bool isDirectory( const QString &absFilePath );
+ bool isDirectory( const TQString &absFilePath );
/**
* Dumps the list of KURL @p urls on standard output, eventually printing @p aMessage if it
@@ -167,14 +167,14 @@ namespace URLUtil
* @param urls URLs to dump.
* @param aMessage Message to be written onto a stdout.
*/
- void dump( const KURL::List &urls, const QString &aMessage = QString::null );
+ void dump( const KURL::List &urls, const TQString &aMessage = TQString::null );
/**
- * Same as QDir::canonicalPath in later versions of Qt. Earlier versions of Qt
+ * Same as TQDir::canonicalPath in later versions of Qt. Earlier versions of Qt
* had this broken, so it's reproduced here.
- * Deprecated, use QDir::canonicalPath instead.
+ * Deprecated, use TQDir::canonicalPath instead.
*/
- QString canonicalPath( const QString & path );
+ TQString canonicalPath( const TQString & path );
/**
* Performs environment variable expansion on @p variable.
@@ -183,7 +183,7 @@ namespace URLUtil
* @return The expanded environment variable value. if the variable
* cannot be expanded, @p variable itself is returned.
*/
- QString envExpand ( const QString &variable );
+ TQString envExpand ( const TQString &variable );
}
@@ -120,8 +120,8 @@ namespace URLUtil
* baseUrl.setPath( "/home/mario/src/kdevelop/" );
* dirUrl.setPath( "/home/mario/src/kdevelop/parts/cvs/" );
- * QString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
- * QString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
+ * TQString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
+ * TQString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
* @endcode
* Note that if you pass a file name in @p url (instead of a directory) or the
@@ -130,25 +130,25 @@ namespace URLUtil
* @param baseDir Base directory for relative URLs.
* @param urls The list of urls to extract the relative paths from.
- * @return A QStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls.
+ * @return A TQStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls.
*/